;
; AutoIt Version: 3.0 beta
; Author: Samuel Murray, with help from people on the AutoIt user forum
; Script name: Wikterma
; Script Function:
;   Creates a bilingual word list from interwiki links on the Wikipedia
;

#include <File.au3>

; Usage
; To use this script, you need a file called URLs.txt in the same directory as the script
; which contains a list of words to look up in the Wikipedia.  Spaces in that list should
; be replaced with underscores (the script doesn't add them automatically).  When the
; script is run, it creates a file named EN-NL.txt, then reads the URLs.txt file, then
; creates URLs and gets them from the web, then saves the downloaded file as foo.txt,
; then searches it for the Dutch word, then writes it and the original word to the EN-NL.txt
; file.

$startup = MsgBox (4, "Wikterma 1.1", "Welcome to Wikterma 1.0" & @CRLF & "by Samuel Murray, 2007" & @CRLF & @CRLF & "This program creates a bilingual word list" & @CRLF & "based on interwiki links on the Wikipedia." & @CRLF & @CRLF & "Have you read the readme.txt file?", "")

If $startup = 7 Then Exit

$startfilename = InputBox ("Name of unilingual word list", "Enter the full name of your initial unilingual word list")
$startfile = FileOpen($startfilename, 0)
$lines = _FileCountLines ($startfilename)

$endfilename = InputBox ("Name of bilingual word list", "Enter a name for your final bilingual word list")
$endfile = FileOpen($endfilename, 1)

$language = InputBox ("Target language name", "Enter the target language's name in that language (default is Dutch)", "Nederlands")
$langcode = InputBox ("Target language code", "Enter the target language's language code in lower case (default is Dutch)", "nl")

$sleeptime = InputBox ("(Optional) Sleep time between fetches", "Enter the time in milliseconds that Wikterma should allow for fetching a web page (default is 2 seconds)", "2000")

$traytip = MsgBox (4, "(Optional) See progress?", "Do you want to see the progress as a traytip?")

For $i = 1 to $lines

$targetword1 = "(empty)"

$sourceword = FileReadLine($startfilename, $i)

$wikipage = InetGet("http://en.wikipedia.org/wiki/" & $sourceword, "temp.txt")

$temphandle = FileOpen('temp.txt', 0)

$targetword0 = StringRegExp(FileRead($temphandle), '(?<=' & $langcode & '\.wikipedia\.org/wiki/).*(?=">' & $language & ')', 1)

If IsArray($targetword0) Then $targetword1 = $targetword0[0]
If IsArray($targetword0) Then FileWriteLine($endfile, $sourceword & " :: " & $targetword1)

If $traytip = 6 Then TrayTip ("Wikterma now parsing...", "Term " & $i & " of " & $lines & ". " & $sourceword & " :: " & $targetword1, 10)

Sleep ($sleeptime)
FileClose ($temphandle)

Next

MsgBox (0, "Done!", "All done!", 10)




